Learn R Programming

mpae (version 0.1.2)

winetaste: Wine taste data

Description

A subset related to the white variant of the Portuguese "Vinho Verde" wine, containing physicochemical information (fixed.acidity, volatile.acidity, citric.acid, residual.sugar, chlorides, free.sulfur.dioxide, total.sulfur.dioxide , density, pH, sulphates and alcohol) and sensory (taste), which indicates the quality of the wine (it is considered good if the median of the wine quality evaluations, made by experts, who evaluated them between 0 = very bad and 10 = very excellent, is not less than 6.

Usage

winetaste

Arguments

Format

A data frame with 1,250 rows and 12 columns:

fixed.acidity

fixed acidity

volatile.acidity

volatile acidity

citric.acid

citric acid

residual.sugar

residual sugar

chlorides

chlorides

free.sulfur.dioxide

free sulfur dioxide

total.sulfur.dioxide

total sulfur dioxide

density

density

pH

pH

sulphates

sulphates

alcohol

alcohol

taste

factor with levels "good" and "bad" indicating the quality of the wine

Details

For more details, consult https://www.vinhoverde.pt/en/ or the reference Cortez et al. (2009).

References

Cortez, P., Cerdeira, A., Almeida, F., Matos, T., & Reis, J. (2009). Modeling wine preferences by data mining from physicochemical properties. Decision Support Systems, 47(4), 547-553.

See Also

winequality

Examples

Run this code
winetaste <- winequality[, names(winequality)!="quality"]
winetaste$taste <- factor(winequality$quality < 6,
                      labels = c('good', 'bad')) # levels = c('FALSE', 'TRUE')
str(winetaste)

Run the code above in your browser using DataLab